#if !defined (_PAGEDUMPFRAME_HH)
#define _PAGEDUMPFRAME_HH

#define BYTES_PER_PAGE 4096
#define BYTES_PER_WORD 4
#define WORDS_PER_PAGE (BYTES_PER_PAGE / BYTES_PER_WORD)

typedef unsigned long word;

class PageDumpFrame {

public:

  // Initialize the frame into a state that indicates that it's not
  // currently holding a page.
  PageDumpFrame ();

  // Read a record and store it in this frame.
  void load (FILE* inputStream);

  // Given another frame, determine whether or not it represents the
  // same page that this one does.
  bool match (PageDumpFrame& matchFrame);

  // Given an old frame that represents that same page, incorporate
  // its old information into this one.
  void update (PageDumpFrame& oldFrame);

  // Output this frame's fetch information.
  void outputFetch (FILE* outputStream);

  // Output this frame's eviction information.
  void outputEvict (FILE* outputStream);

  // Return the page number that this frame represents.
  unsigned int getPageNumber () { return pageNumber; }

  // Set or unset this frame as representing a compulsory fault.
  void setCompulsory (bool newCompulsory) {
    compulsory = newCompulsory;
  }

  // A little debugging code.
  bool isDirty () { return dirty; }

private:

  unsigned int pageNumber;
  bool compulsory;
  bool dirty;
  word fetchedImage[WORDS_PER_PAGE];
  word evictedImage[WORDS_PER_PAGE];

};

#endif // _PAGEDUMPFRAME_HH
